Method: Shell.install_system_commands

Defined in:
lib/shell.rb

.install_system_commands(pre = "sys_") ⇒ Object

call-seq:

install_system_commands(pre = "sys_")

Convenience method for Shell::CommandProcessor.install_system_commands. Defines instance methods representing all the executable files found in Shell.default_system_path, with the given prefix prepended to their names.

Shell.install_system_commands
Shell.new.sys_echo("hello") # => hello


415
416
417
# File 'lib/shell.rb', line 415

def Shell.install_system_commands(pre = "sys_")
  CommandProcessor.install_system_commands(pre)
end